"use strict";
const axios_1 = require("axios");
const mqtt_topping_1 = require("mqtt-topping");
const Logger = require("bunyan");
function delay(time) {
    return new Promise(resolve => setTimeout(resolve, time));
}
function createClientId(serviceId, device) {
    const uuid = Math.random().toString(16).substr(2, 8);
    return `${serviceId}-${device}-${uuid}`;
}
module.exports = async function init(url, serviceId, { timeout = 2000, retryDelay = 10000 } = {}) {
    const logger = Logger.createLogger({
        name: serviceId,
        level: "debug",
        serializers: { error: Logger.stdSerializers.err }
    });
    async function query() {
        logger.info({ url }, "Querying bootstrap data");
        try {
            const response = await axios_1.default.get(url, { timeout });
            return response.data;
        }
        catch (error) {
            logger.error({ error: error.message }, `Query failed. Retrying in ${retryDelay}ms...`);
            await delay(retryDelay);
            return await query();
        }
    }
    const data = await query();
    logger.info({ data }, "Bootstrap data received");
    const { device, tcpBrokerUri, httpBrokerUri, configServerUri } = data;
    const clientId = createClientId(serviceId, device);
    logger.info({ tcpBrokerUri, httpBrokerUri, clientId }, "Connecting to Broker");
    const mqttClient = mqtt_topping_1.default.connect(tcpBrokerUri, httpBrokerUri, { clientId });
    mqttClient.on("connect", () => { logger.info("Connected to Broker"); });
    mqttClient.on("close", () => { logger.error("Disconnected from Broker"); });
    mqttClient.on("error", () => { logger.error("Error Connecting to Broker"); });
    async function queryConfig(configPath, version = "master") {
        return axios_1.default(`${configServerUri}/${version}/${configPath}`);
    }
    return { logger, mqttClient, queryConfig, data };
};
//# sourceMappingURL=main.js.map